@@ -30,17 +30,21 @@ import (
 
 	"github.com/goplus/gop/cmd/internal/base"
 	"github.com/goplus/gop/format"
+
+	xformat "github.com/goplus/gop/x/format"
 )
 
 // Cmd - gop go
 var Cmd = &base.Command{
-	UsageLine: "gop fmt [-n] path ...",
+	UsageLine: "gop fmt [-n --smart --mvgo] path ...",
 	Short:     "Format Go+ packages",
 }
 
 var (
 	flag        = &Cmd.Flag
 	flagNotExec = flag.Bool("n", false, "prints commands that would be executed.")
+	flagMoveGo  = flag.Bool("mvgo", false, "move .go files to .gop files (only available in `--smart` mode).")
+	flagSmart   = flag.Bool("smart", false, "convert Go code style into Go+ style.")
 )
 
 func init() {
@@ -59,12 +63,17 @@ var (
 	rootDir = ""
 )
 
-func gopfmt(path string) (err error) {
+func gopfmt(path string, smart, mvgo bool) (err error) {
 	src, err := ioutil.ReadFile(path)
 	if err != nil {
 		return
 	}
-	target, err := format.Source(src)
+	var target []byte
+	if smart {
+		target, err = xformat.GopstyleSource(src, path)
+	} else {
+		target, err = format.Source(src, path)
+	}
 	if err != nil {
 		return
 	}
@@ -72,6 +81,13 @@ func gopfmt(path string) (err error) {
 		return
 	}
 	fmt.Println(path)
+	if mvgo {
+		newPath := strings.TrimSuffix(path, ".go") + ".gop"
+		if err = os.WriteFile(newPath, target, 0666); err != nil {
+			return
+		}
+		return os.Remove(path)
+	}
 	return writeFileWithBackup(path, target)
 }
 
@@ -108,13 +124,23 @@ func walk(path string, d fs.DirEntry, err error) error {
 			if *flagNotExec {
 				fmt.Println("gop fmt", path)
 			} else {
-				err = gopfmt(path)
+				smart := *flagSmart
+				mvgo := smart && *flagMoveGo
+				err = gopfmt(path, smart && (mvgo || ext != ".go"), mvgo)
+				if err != nil {
+					report(err)
+				}
 			}
 		}
 	}
 	return err
 }
 
+func report(err error) {
+	fmt.Println(err)
+	os.Exit(2)
+}
+
 func runCmd(cmd *base.Command, args []string) {
 	err := flag.Parse(args)
 	if err != nil {
